@@ -32,17 +32,18 @@ GribInfo <- function(grib.file, file.type = "grib2") {
         inv <- system(paste0("wgrib ", grib.file), " -s", intern = TRUE)
         grid <- NULL
     } else {
-        stop(paste0("Did not recognise file type ", file.type, ".  Please use \"grib2\" or \"grib.\""))
+        stop(paste0("Did not recognise file type ", file.type, ".  Please use \"grib2\" or \"grib1\"."))
     }
     return(list(inventory = inv, grid = grid))
 }
 
-ReadGrib <- function(file.names, levels, variables, domain = NULL, domain.type = "latlon", file.type = "grib2", missing.data = NULL) {
+ReadGrib <- function(file.names, levels, variables, forecasts = NULL, domain = NULL, domain.type = "latlon", file.type = "grib2", missing.data = NULL) {
     #This is a function to read forecast data from Grib files
     #INPUTS
     #    FILE.NAMES - Vector of grib file names
     #    VARIABLES - data to extract
     #    LEVELS - which levels to extract data from
+    #    FORECASTS - A string indicating the forecast to extract.  Default NULL: return everything
     #    DOMAIN - Region to extract data from, in c(LEFT LON, RIGHT LON, TOP LAT, BOTTOM LAT), west negative
     #    DOMAIN.TYPE - Either "latlon" (default), where the domain is a latitude/longitude box, or "index", where the model is subsetted based on the node index
     #    FILE.TYPE - whether this is a grib1 or a grib2 file
@@ -94,12 +95,25 @@ ReadGrib <- function(file.names, levels, variables, domain = NULL, domain.type =
         } else {
             match.str <- paste0(match.str, ")")
        }
+   
+        match.str.lst <- strsplit(match.str, split = "")[[1]]
+        match.str <- paste(match.str.lst[1:(length(match.str.lst) - 1)], collapse = "")
     
+        if(length(forecasts) > 0 & !is.null(forecasts)) {
+            match.str <- paste(match.str, "):(", sep = "")
+            for(fcst in forecasts) {
+                match.str <- paste(match.str, fcst, "|", sep = "")
+            }
+        } else {
+            match.str <- paste0(match.str, ")")
+       }
+   
         match.str.lst <- strsplit(match.str, split = "")[[1]]
         match.str <- paste(match.str, '"', sep = "")
         match.str <- paste(match.str.lst[1:(length(match.str.lst) - 1)], collapse = "")
         match.str <- paste(match.str, ")\"", sep = "")
-   
+  
+        print(match.str) 
         if(!is.null(missing.data) & !is.numeric(missing.data)) {
             warning(paste("Your value", missing.data, " for missing data does not appear to be a number!"))
         }
